@@ -96,6 +96,10 @@ goc_canvas_draw (GtkWidget *widget, cairo_t *cr)
 	cairo_translate (cr, -x, -y);
 	goc_item_get_bounds (GOC_ITEM (canvas->root),&x0, &y0, &x1, &y1);
 	for (i= 0; i  < l->num_rectangles; i++) {
+		cairo_save (cr);
+		cairo_rectangle (cr, l->rectangles[i].x, l->rectangles[i].y,
+		                 l->rectangles[i].width, l->rectangles[i].height);
+		cairo_clip (cr);
 		clip_x1 = l->rectangles[i].x;
 		clip_y1 = l->rectangles[i].y;
 		clip_x2 = clip_x1 + l->rectangles[i].width;
@@ -114,6 +118,7 @@ goc_canvas_draw (GtkWidget *widget, cairo_t *cr)
 			canvas->cur_event = (GdkEvent *) event;
 			goc_item_draw_region (GOC_ITEM (canvas->root), cr, ax0, ay0, ax1, ay1);
 		}
+		cairo_restore (cr);
 	}
 	cairo_rectangle_list_destroy (l);
 	return TRUE;
@@ -322,6 +327,9 @@ goc_canvas_class_init (GObjectClass *klass)
 	klass->dispose = goc_canvas_dispose;
 
 #ifdef GOFFICE_WITH_GTK
+#ifdef HAVE_GTK_WIDGET_CLASS_SET_CSS_NAME
+	gtk_widget_class_set_css_name (widget_klass, "canvas");
+#endif
 	widget_klass->draw = goc_canvas_draw;
 	widget_klass->realize = goc_canvas_realize;
 	widget_klass->unrealize = goc_canvas_unrealize;
@@ -395,7 +403,7 @@ goc_canvas_get_root (GocCanvas *canvas)
  * goc_canvas_get_width:
  * @canvas: #GocCanvas
  *
- * Returns: (transfer none): the width of the widget visible region.
+ * Returns: the width of the widget visible region.
  **/
 int
 goc_canvas_get_width (GocCanvas *canvas)
