@@ -213,34 +213,35 @@ libgoffice_init (void)
 	_goc_plugin_services_init ();
 	install_icons ();
 #endif
-	(void) GO_TYPE_PLUGIN_LOADER_MODULE;
-	(void) GOG_TYPE_GRAPH;
-	(void) GOG_TYPE_CHART;
-	(void) GOG_TYPE_PLOT;
-	(void) GOG_TYPE_SERIES;
-	(void) GOG_TYPE_SERIES_ELEMENT;
-	(void) GOG_TYPE_LEGEND;
-	(void) GOG_TYPE_AXIS;
-	(void) GOG_TYPE_AXIS_LINE;
-	(void) GOG_TYPE_COLOR_SCALE;
-	(void) GOG_TYPE_LABEL;
-	(void) GOG_TYPE_GRID;
-	(void) GOG_TYPE_GRID_LINE;
+	g_type_ensure (GO_TYPE_PLUGIN_LOADER_MODULE);
+	g_type_ensure (GOG_TYPE_GRAPH);
+	g_type_ensure (GOG_TYPE_CHART);
+	g_type_ensure (GOG_TYPE_PLOT);
+	g_type_ensure (GOG_TYPE_SERIES);
+	g_type_ensure (GOG_TYPE_SERIES_ELEMENT);
+	g_type_ensure (GOG_TYPE_LEGEND);
+	g_type_ensure (GOG_TYPE_AXIS);
+	g_type_ensure (GOG_TYPE_AXIS_LINE);
+	g_type_ensure (GOG_TYPE_COLOR_SCALE);
+	g_type_ensure (GOG_TYPE_LABEL);
+	g_type_ensure (GOG_TYPE_GRID);
+	g_type_ensure (GOG_TYPE_GRID_LINE);
 #ifdef GOFFICE_WITH_LASEM
-	(void) GOG_TYPE_EQUATION;
+	g_type_ensure (GOG_TYPE_EQUATION);
 #endif
-	(void) GOG_TYPE_ERROR_BAR;
-	(void) GOG_TYPE_REG_EQN;
-	(void) GOG_TYPE_SERIES_LABELS;
-	(void) GOG_TYPE_DATA_LABEL;
-	(void) GOG_TYPE_SERIES_LINES;
-	(void) GO_TYPE_DATA_SCALAR_VAL;
-	(void) GO_TYPE_DATA_SCALAR_STR;
-	(void) GOG_3D_BOX_TYPE;
-	(void) GO_TYPE_EMF;
-	(void) GO_TYPE_PIXBUF;
-	(void) GO_TYPE_SPECTRE;
-	(void) GO_TYPE_SVG;
+	g_type_ensure (GOG_TYPE_ERROR_BAR);
+	g_type_ensure (GOG_TYPE_REG_EQN);
+	g_type_ensure (GOG_TYPE_SERIES_LABELS);
+	g_type_ensure (GOG_TYPE_DATA_LABEL);
+	g_type_ensure (GOG_TYPE_SERIES_LINES);
+	g_type_ensure (GO_TYPE_DATA_SCALAR_VAL);
+	g_type_ensure (GO_TYPE_DATA_SCALAR_STR);
+	g_type_ensure (GOG_3D_BOX_TYPE);
+	g_type_ensure (GO_TYPE_EMF);
+	g_type_ensure (GO_TYPE_PIXBUF);
+	g_type_ensure (GO_TYPE_SPECTRE);
+	g_type_ensure (GO_TYPE_SVG);
+
 	_gog_themes_init ();
 	_go_number_format_init ();
 	_go_currency_date_format_init ();
@@ -264,6 +265,7 @@ libgoffice_shutdown (void)
 	_go_fonts_shutdown ();
 	_go_conf_shutdown ();
 #ifdef GOFFICE_WITH_GTK
+	_go_gtk_shutdown ();
 	_goc_plugin_services_shutdown ();
 #endif
 	_gog_plugin_services_shutdown ();
