@@ -21,6 +21,7 @@
 
 #include <goffice/goffice-config.h>
 #include <goffice/goffice.h>
+#include <glib/gi18n-lib.h>
 
 #include <string.h>
 #include <stdlib.h>
@@ -168,11 +169,14 @@ gog_dataset_sax_save (GogDataset const *set, GsfXMLOut *output, gpointer user)
 		if (dat == NULL)
 			continue;
 
+		tmp = go_data_serialize (dat, user);
+		/* only save the data if there is some valid content, see #46 */
+		if (tmp == NULL || *tmp == 0)
+			continue;
 		gsf_xml_out_start_element (output, "dimension");
 		gsf_xml_out_add_int (output, "id", i);
 		gsf_xml_out_add_cstr (output, "type",
 			G_OBJECT_TYPE_NAME (dat));
-		tmp = go_data_serialize (dat, user);
 		gsf_xml_out_add_cstr (output, NULL, tmp);
 		g_free (tmp);
 		gsf_xml_out_end_element (output); /* </dimension> */
@@ -290,7 +294,7 @@ gogo_dim_start (GsfXMLIn *xin, xmlChar const **attrs)
 		g_warning ("unknown type '%s' for dimension `%s' of class `%s'",
 			   type_str, dim_str, G_OBJECT_TYPE_NAME (state->obj));
 		return;
-	} else if (!g_type_is_a (type, GO_TYPE_DATA)) {
+	} else if (!g_type_is_a (type, GO_TYPE_DATA) || G_TYPE_IS_ABSTRACT (type)) {
 		g_warning ("type '%s' is invalid as dimension `%s' of class `%s'",
 			   type_str, dim_str, G_OBJECT_TYPE_NAME (state->obj));
 		return;
@@ -370,7 +374,7 @@ gogo_prop_start (GsfXMLIn *xin, xmlChar const **attrs)
 			g_warning ("unknown type '%s' for property `%s' of class `%s'",
 				   type_str, prop_str, G_OBJECT_TYPE_NAME (state->obj));
 			return;
-		} else if (!g_type_is_a (type, prop_type)) {
+		} else if (!g_type_is_a (type, prop_type) || G_TYPE_IS_ABSTRACT (type)) {
 			g_warning ("invalid type '%s' for property `%s' of class `%s'",
 				   type_str, prop_str, G_OBJECT_TYPE_NAME (state->obj));
 			return;
@@ -414,13 +418,31 @@ gogo_prop_end (GsfXMLIn *xin, G_GNUC_UNUSED GsfXMLBlob *unknown)
 		g_value_set_object (&val, G_OBJECT (obj));
 		g_object_unref (obj);
 	} else {
+		gboolean ok = FALSE;
 		if (content == NULL && prop_ftype != G_TYPE_BOOLEAN) {
 			g_warning ("could not convert NULL to type `%s' for property `%s'",
 				   g_type_name (prop_type), state->prop_spec->name);
 			return;
 		}
 
-		if (!gsf_xml_gvalue_from_str (&val, prop_type, content)) {
+		if (prop_type == G_TYPE_BOOLEAN) {
+			// We've managed to save some files with translated
+			// booleans.  Try to recover.
+			if (g_str_equal (content, _("TRUE"))) {
+				g_value_init (&val, prop_type);
+				g_value_set_boolean (&val, TRUE);
+				ok = TRUE;
+			} else if (g_str_equal (content, _("FALSE"))) {
+				g_value_init (&val, prop_type);
+				g_value_set_boolean (&val, FALSE);
+				ok = TRUE;
+			}
+		}
+
+		if (!ok)
+			ok = gsf_xml_gvalue_from_str (&val, prop_type, content);
+
+		if (!ok) {
 			g_warning ("could not convert string to type `%s' for property `%s'",
 				   g_type_name (prop_type), state->prop_spec->name);
 			return;
@@ -452,8 +474,10 @@ gogo_start (GsfXMLIn *xin, xmlChar const **attrs)
 			res = (GogObject *)gog_plot_new_by_name (type);
 			if (NULL == res)
 				res = (GogObject *)gog_trend_line_new_by_name (type);
-		} else
+		} else if (g_type_is_a (t, GOG_TYPE_OBJECT) && !G_TYPE_IS_ABSTRACT (t))
 			res = g_object_new (t, NULL);
+		else
+			res = NULL;
 
 		if (res == NULL) {
 			g_warning ("unknown type '%s'", type);
