@@ -963,6 +963,7 @@ gog_series_dataset_dim_changed (GogDataset *set, int dim_i)
 			? go_data_get_scalar_string (name_src) : NULL;
 		gog_object_set_name (GOG_OBJECT (set), name, NULL);
 	}
+	gog_series_check_validity (series);
 }
 
 static void
@@ -1024,8 +1025,9 @@ gog_series_check_validity (GogSeries *series)
 
 	desc = &series->plot->desc.series;
 	for (i = series->plot->desc.series.num_dim; i-- > 0; )
-		if (series->values[i].data == NULL &&
-		    desc->dim[i].priority == GOG_SERIES_REQUIRED) {
+		if (desc->dim[i].priority == GOG_SERIES_REQUIRED && (
+		      series->values[i].data == NULL ||
+		      !go_data_has_value (series->values[i].data))) {
 			series->is_valid = FALSE;
 			return;
 		}
